write — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# write

poscar_supercell.write(filename: str, cartesian: bool = False, xyz: bool = False)

  Just a convenience method to save the content into a file.

  Parameters:

    - filename (str) – the name of the file to be written

    - cartesian (bool) – Do you prefer the output position in Cartesian coords (True)? Default is False

    - xyz (bool) – Do you want to write an .xyz file? the .xyz extension will be added to filename. Default is False